﻿
export function init(element, componentInstance) {

    if (typeof google == 'undefined') {
        console.error('Google Autocomplete script is missing. Please add it in index.html:', '<script src="https://maps.googleapis.com/maps/api/js?key=PUBLIC_KEY&libraries=places&callback=onMapAPILoaded"></script>');
    }

    var googleDefaultBounds = new google.maps.LatLngBounds(
        new google.maps.LatLng(45.50, 5.7), // sw
        new google.maps.LatLng(48.26, 11.0) // ne
    );

    var autocomplete = new google.maps.places.Autocomplete(
        element,
        {
            types: ['(cities)']
            ,bounds: googleDefaultBounds
            //,componentRestrictions: { country: "CH" }
        }
    );

    google.maps.event.addListener(autocomplete, 'place_changed', async function () {
        var place = autocomplete.getPlace();
        if (place.geometry) {

            var latLng = place.geometry.location;
            var newLat = latLng.lat();
            var newLng = latLng.lng();

            await componentInstance.invokeMethodAsync("OnJSPlaceChanged", { formattedAddress: place.formatted_address, lat: newLat, lng: newLng });
        }
    });

    return {
        dispose: () => dispose()
    };
}

export async function getCity(lat, lng) {

    let city = null;
    let cityAlt = null;
    let country = null;
    let countryCode = null;

    const getAddress = latlng => {
        return new Promise((resolve, reject) => {
            new google.maps.Geocoder().geocode({ 'latLng': latlng }, (results, status) => {
                if (status === google.maps.GeocoderStatus.OK) {
                    resolve(results);
                }
                else {
                    reject(status);
                }
            });
        });
    };

    try {
        let results = await getAddress(new google.maps.LatLng(lat, lng));
        if (results[1]) {

            var c, lc, component;

            for (var r = 0, rl = results.length; r < rl; r += 1) {
                var result = results[r];

                if (!city && result.types[0] === 'locality') {
                    for (c = 0, lc = result.address_components.length; c < lc; c += 1) {
                        component = result.address_components[c];

                        if (component.types[0] === 'locality') {
                            city = component.long_name;
                            break;
                        }
                    }
                }
                else if (!city && !cityAlt && result.types[0] === 'administrative_area_level_1') {
                    for (c = 0, lc = result.address_components.length; c < lc; c += 1) {
                        component = result.address_components[c];

                        if (component.types[0] === 'administrative_area_level_1') {
                            cityAlt = component.long_name;
                            break;
                        }
                    }
                }
                else if (!country && result.types[0] === 'country') {
                    country = result.address_components[0].long_name;
                    countryCode = result.address_components[0].short_name;
                }

                if (city && country) {
                    break;
                }
            }
        }
    }
    catch {
        // Nothing...
    }

    let response = null;

    if (city !== null || cityAlt !== null || country !== null || countryCode !== null) {
        response = {
            name: city ?? '',
            nameAlt: cityAlt ?? '',
            country: country ?? '',
            countryCode: countryCode ?? ''
        };
    }

    return response;
} 

export function dispose() {

    let elements = document.getElementsByClassName('pac-container');
    if (elements) {
        for (var i = elements.length - 1; i >= 0; i--) {
            elements[i].remove();
        }
    }

    let heads = document.getElementsByTagName('head');
    if (heads) {
        for (let i = heads.length - 1; i >= 0; i--) {

            let head = heads[i];

            for (let j = head.children.length - 1; j >= 0; j--) {
                let child = head.children[j];

                if (child.innerHTML.startsWith('.pac-container')) {
                    child.remove();
                }
            }
        }
    }
}